@@ -5,7 +5,7 @@ FAKE = False
 
 DEBUG = True
 FULLSCREEN = True
-MOSTRAR_CURSOR = True
+SHOW_CURSOR = False
 
 NPOINTS = 5
 MISCLICK_THRESHOLD = 30
@@ -21,4 +21,4 @@ DEFAULT_LOCALE = 'en_US'
 RESOURCES_PATH = join(split(__file__)[0], 'resources')
 
 FAST_START = True
-AUTO_CLOSE = False
+AUTO_CLOSE = True
